package com.example.nto.controller;

import com.example.nto.entity.Employee;
import com.example.nto.repository.CodeRepository;
import com.example.nto.service.EmployeeService;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PatchMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.Optional;

public class EmployeeController {
    private final EmployeeService employeeService;
    private final CodeRepository codeRepository;

    public EmployeeController(EmployeeService employeeService, CodeRepository codeRepository) {
        this.employeeService = employeeService;
        this.codeRepository = codeRepository;
    }

    /**
     * Эндпоинт для проверки присутствия логина в емплоеееее таблице
     *
     * @param login Искомый логин
     * @return статус код, смотри документацию к тз
     */
    @GetMapping("/api/{login}/auth")
    public ResponseEntity<String> authAttempt(@PathVariable String login) {
        try {
            if (employeeService.checkEmployeeExists(login)) {
                return ResponseEntity.status(HttpStatus.ACCEPTED).build(); // Логин найден ДВЕСТИ
            }
            return ResponseEntity.status(HttpStatus.UNAUTHORIZED).build(); // Логин не найден 401 неавторизован

        } catch (
                Exception e) // Я понял статус "что-то пошло не так", как то, что произошла какая-то ошибка. Вообще по идее должен быть статус 500, но допустим
        {
            return ResponseEntity.status(HttpStatus.BAD_REQUEST).build();
        }
    }


    /**
     * Получить информацию по емплоеееее
     *
     * @param login логин пользователя
     * @return емплоеееееее иначе 401 бан бан бан бан, а если ошибка, то 400 БАААААН
     */
    @GetMapping("/api/{login}/info")
    public ResponseEntity<Employee> getEmployeeInfo(@PathVariable String login) {
        try {
            Optional<Employee> employee = employeeService.getEmployeeInfo(login);
            return employee.map(ResponseEntity::ok).orElseGet(() -> ResponseEntity.status(HttpStatus.UNAUTHORIZED).build());
        } catch (
                Exception e) // Я понял статус "что-то пошло не так", как то, что произошла какая-то ошибка. Вообще по идее должен быть статус 500, но допустим
        {
            return ResponseEntity.status(HttpStatus.BAD_REQUEST).build();
        }
    }

    /**
     * Проверка на дверь открыть не открыть
     * @param login логин входящего
     * @param value код двери
     * @return статус код отвта
     */
    @PatchMapping("api/{login}/open")
    public ResponseEntity<String> openDoorAttempt(@PathVariable String login, @RequestBody Long value) {
        try {
            if (!employeeService.checkEmployeeExists(login)) {
                return ResponseEntity.status(HttpStatus.UNAUTHORIZED).build();
            }

            if (!codeRepository.existsByValue(value)) {
                return ResponseEntity.status(HttpStatus.BAD_REQUEST).build();
            }

            employeeService.updateLastVisit(login);
            return ResponseEntity.status(HttpStatus.ACCEPTED).build();

        } catch (Exception e) {
            return ResponseEntity.status(HttpStatus.BAD_REQUEST).build();
        }

    }


}
